Documentation
¶
Index ¶
- type FRBCActuatorDescriptor
- func (d *FRBCActuatorDescriptor) GetDiagnosticLabel() *string
- func (d *FRBCActuatorDescriptor) GetID() *generated.ID
- func (d *FRBCActuatorDescriptor) GetOperationModes() []*FRBCOperationMode
- func (d *FRBCActuatorDescriptor) GetSupportedCommodities() []generated.Commodity
- func (d *FRBCActuatorDescriptor) GetTimers() []*common.Timer
- func (d *FRBCActuatorDescriptor) GetTransitions() []*common.Transition
- type FRBCActuatorStatus
- func (s *FRBCActuatorStatus) GetActiveOperationModeID() *generated.ID
- func (s *FRBCActuatorStatus) GetActuatorID() *generated.ID
- func (s *FRBCActuatorStatus) GetMessageID() *generated.ID
- func (s *FRBCActuatorStatus) GetMessageType() string
- func (s *FRBCActuatorStatus) GetOperationModeFactor() float64
- func (s *FRBCActuatorStatus) GetPreviousOperationModeID() *generated.ID
- func (s *FRBCActuatorStatus) GetTransitionTimestamp() *time.Time
- type FRBCFillLevelTargetProfile
- type FRBCFillLevelTargetProfileElement
- type FRBCInstruction
- func (i *FRBCInstruction) GetAbnormalCondition() bool
- func (i *FRBCInstruction) GetActuatorID() *generated.ID
- func (i *FRBCInstruction) GetExecutionTime() time.Time
- func (i *FRBCInstruction) GetID() *generated.ID
- func (i *FRBCInstruction) GetMessageID() *generated.ID
- func (i *FRBCInstruction) GetMessageType() string
- func (i *FRBCInstruction) GetOperationMode() *generated.ID
- func (i *FRBCInstruction) GetOperationModeFactor() float64
- type FRBCLeakageBehaviour
- type FRBCLeakageBehaviourElement
- type FRBCOperationMode
- type FRBCOperationModeElement
- type FRBCStorageDescription
- func (sd *FRBCStorageDescription) GetDiagnosticLabel() *string
- func (sd *FRBCStorageDescription) GetFillLevelLabel() *string
- func (sd *FRBCStorageDescription) GetFillLevelRange() *common.NumberRange
- func (sd *FRBCStorageDescription) GetProvidesFillLevelTargetProfile() bool
- func (sd *FRBCStorageDescription) GetProvidesLeakageBehaviour() bool
- func (sd *FRBCStorageDescription) GetProvidesUsageForecast() bool
- type FRBCStorageStatus
- type FRBCSystemDescription
- func (sd *FRBCSystemDescription) GetActuators() []*FRBCActuatorDescriptor
- func (sd *FRBCSystemDescription) GetMessageID() *generated.ID
- func (sd *FRBCSystemDescription) GetMessageType() string
- func (sd *FRBCSystemDescription) GetStorage() *FRBCStorageDescription
- func (sd *FRBCSystemDescription) GetValidFrom() time.Time
- type FRBCTimerStatus
- type FRBCUsageForecast
- type FRBCUsageForecastElement
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FRBCActuatorDescriptor ¶
type FRBCActuatorDescriptor struct {
DiagnosticLabel *string `` /* 181-byte string literal not displayed */
ID *generated.ID `` /* 171-byte string literal not displayed */
OperationModes []*FRBCOperationMode `json:"operation_modes" description:"Provided FRBC.OperationModes associated with this actuator" min_items:"1" max_items:"100"`
SupportedCommodities []generated.Commodity `json:"supported_commodities" description:"List of all supported Commodities." min_items:"1" max_items:"4"`
Timers []*common.Timer `json:"timers,omitempty" description:"List of Timers associated with this actuator" max_items:"1000"`
Transitions []*common.Transition `` /* 139-byte string literal not displayed */
}
FRBCActuatorDescriptor represents the description of an FRBC actuator.
func NewFRBCActuatorDescriptor ¶
func NewFRBCActuatorDescriptor(id *generated.ID, operationModes []*FRBCOperationMode, supportedCommodities []generated.Commodity, diagnosticLabel *string, timers []*common.Timer, transitions []*common.Transition) (*FRBCActuatorDescriptor, error)
NewFRBCActuatorDescriptor creates a new instance of FRBCActuatorDescriptor if validated, otherwise returns an error.
func (*FRBCActuatorDescriptor) GetDiagnosticLabel ¶
func (d *FRBCActuatorDescriptor) GetDiagnosticLabel() *string
GetDiagnosticLabel returns the diagnostic label of the actuator descriptor.
func (*FRBCActuatorDescriptor) GetID ¶
func (d *FRBCActuatorDescriptor) GetID() *generated.ID
GetID returns the ID of the actuator descriptor.
func (*FRBCActuatorDescriptor) GetOperationModes ¶
func (d *FRBCActuatorDescriptor) GetOperationModes() []*FRBCOperationMode
GetOperationModes returns the operation modes of the actuator descriptor.
func (*FRBCActuatorDescriptor) GetSupportedCommodities ¶
func (d *FRBCActuatorDescriptor) GetSupportedCommodities() []generated.Commodity
GetSupportedCommodities returns the supported commodities of the actuator descriptor.
func (*FRBCActuatorDescriptor) GetTimers ¶
func (d *FRBCActuatorDescriptor) GetTimers() []*common.Timer
GetTimers returns the timers of the actuator descriptor.
func (*FRBCActuatorDescriptor) GetTransitions ¶
func (d *FRBCActuatorDescriptor) GetTransitions() []*common.Transition
GetTransitions returns the transitions of the actuator descriptor.
type FRBCActuatorStatus ¶
type FRBCActuatorStatus struct {
ActiveOperationModeID *generated.ID `json:"active_operation_mode_id" description:"ID of the FRBC.OperationMode that is presently active."`
ActuatorID *generated.ID `json:"actuator_id" description:"ID of the actuator this message refers to"`
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"Type of the message"`
OperationModeFactor float64 `json:"operation_mode_factor" description:"The number indicates the factor with which the FRBC.OperationMode is configured"`
PreviousOperationModeID *generated.ID `json:"previous_operation_mode_id,omitempty" description:"ID of the FRBC.OperationMode that was active before the present one"`
TransitionTimestamp *time.Time `` /* 164-byte string literal not displayed */
}
FRBCActuatorStatus represents a FRBC actuator status model.
func NewFRBCActuatorStatus ¶
func NewFRBCActuatorStatus(activeOperationModeID, actuatorID *generated.ID, operationModeFactor float64, previousOperationModeID *generated.ID, transitionTimestamp *time.Time) (*FRBCActuatorStatus, error)
NewFRBCActuatorStatus creates a new instance of FRBCActuatorStatus.
func (*FRBCActuatorStatus) GetActiveOperationModeID ¶
func (s *FRBCActuatorStatus) GetActiveOperationModeID() *generated.ID
GetActiveOperationModeID returns the active operation mode ID.
func (*FRBCActuatorStatus) GetActuatorID ¶
func (s *FRBCActuatorStatus) GetActuatorID() *generated.ID
GetActuatorID returns the actuator ID.
func (*FRBCActuatorStatus) GetMessageID ¶
func (s *FRBCActuatorStatus) GetMessageID() *generated.ID
GetMessageID returns the message ID.
func (*FRBCActuatorStatus) GetMessageType ¶
func (s *FRBCActuatorStatus) GetMessageType() string
GetMessageType returns the message type.
func (*FRBCActuatorStatus) GetOperationModeFactor ¶
func (s *FRBCActuatorStatus) GetOperationModeFactor() float64
GetOperationModeFactor returns the operation mode factor.
func (*FRBCActuatorStatus) GetPreviousOperationModeID ¶
func (s *FRBCActuatorStatus) GetPreviousOperationModeID() *generated.ID
GetPreviousOperationModeID returns the previous operation mode ID.
func (*FRBCActuatorStatus) GetTransitionTimestamp ¶
func (s *FRBCActuatorStatus) GetTransitionTimestamp() *time.Time
GetTransitionTimestamp returns the transition timestamp.
type FRBCFillLevelTargetProfile ¶
type FRBCFillLevelTargetProfile struct {
Elements []*FRBCFillLevelTargetProfileElement `` /* 194-byte string literal not displayed */
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBCFillLevelTargetProfile" const:"true"`
StartTime time.Time `json:"start_time" description:"Time at which the FRBC.FillLevelTargetProfile starts."`
}
FRBCFillLevelTargetProfile represents a target profile for fill levels.
func NewFRBCFillLevelTargetProfile ¶
func NewFRBCFillLevelTargetProfile(elements []*FRBCFillLevelTargetProfileElement, startTime time.Time) (*FRBCFillLevelTargetProfile, error)
NewFRBCFillLevelTargetProfile creates a new instance of FRBCFillLevelTargetProfile if validated, otherwise returns an error.
func (*FRBCFillLevelTargetProfile) GetElements ¶
func (p *FRBCFillLevelTargetProfile) GetElements() []*FRBCFillLevelTargetProfileElement
GetElements returns the elements of the fill level target profile.
func (*FRBCFillLevelTargetProfile) GetMessageID ¶
func (p *FRBCFillLevelTargetProfile) GetMessageID() *generated.ID
GetMessageID returns the message ID of the fill level target profile.
func (*FRBCFillLevelTargetProfile) GetMessageType ¶
func (p *FRBCFillLevelTargetProfile) GetMessageType() string
GetMessageType returns the message type of the fill level target profile.
func (*FRBCFillLevelTargetProfile) GetStartTime ¶
func (p *FRBCFillLevelTargetProfile) GetStartTime() time.Time
GetStartTime returns the start time of the fill level target profile.
type FRBCFillLevelTargetProfileElement ¶
type FRBCFillLevelTargetProfileElement struct {
Duration *common.Duration `json:"duration" description:"The duration of the element"`
FillLevelRange *common.NumberRange `` /* 141-byte string literal not displayed */
}
FRBCFillLevelTargetProfileElement represents an element of FRBC fill level target profile.
func NewFRBCFillLevelTargetProfileElement ¶
func NewFRBCFillLevelTargetProfileElement(duration *common.Duration, fillLevelRange *common.NumberRange) (*FRBCFillLevelTargetProfileElement, error)
NewFRBCFillLevelTargetProfileElement creates a new instance of FRBCFillLevelTargetProfileElement if validated, otherwise returns an error.
func (*FRBCFillLevelTargetProfileElement) GetDuration ¶
func (e *FRBCFillLevelTargetProfileElement) GetDuration() *common.Duration
GetDuration returns the duration of the FRBCFillLevelTargetProfileElement.
func (*FRBCFillLevelTargetProfileElement) GetFillLevelRange ¶
func (e *FRBCFillLevelTargetProfileElement) GetFillLevelRange() *common.NumberRange
GetFillLevelRange returns the fill level range of the FRBCFillLevelTargetProfileElement.
type FRBCInstruction ¶
type FRBCInstruction struct {
AbnormalCondition bool `json:"abnormal_condition" description:"Indicates if this is an instruction during an abnormal condition"`
ActuatorID *generated.ID `json:"actuator_id" description:"ID of the actuator this instruction belongs to"`
ExecutionTime time.Time `json:"execution_time" description:"Time when instruction should be executed"`
ID *generated.ID `` /* 173-byte string literal not displayed */
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBC.Instruction"`
OperationMode *generated.ID `json:"operation_mode" description:"ID of the FRBC.OperationMode that should be activated"`
OperationModeFactor float64 `` /* 206-byte string literal not displayed */
}
FRBCInstruction represents an instruction in FRBC.
func NewFRBCInstruction ¶
func NewFRBCInstruction(abnormalCondition bool, actuatorID, operationMode *generated.ID, executionTime time.Time, operationModeFactor float64) (*FRBCInstruction, error)
NewFRBCInstruction creates a new instance of FRBCInstruction if validated, otherwise returns an error.
func (*FRBCInstruction) GetAbnormalCondition ¶
func (i *FRBCInstruction) GetAbnormalCondition() bool
GetAbnormalCondition returns if the instruction is for an abnormal condition.
func (*FRBCInstruction) GetActuatorID ¶
func (i *FRBCInstruction) GetActuatorID() *generated.ID
GetActuatorID returns the actuator ID.
func (*FRBCInstruction) GetExecutionTime ¶
func (i *FRBCInstruction) GetExecutionTime() time.Time
GetExecutionTime returns the execution time.
func (*FRBCInstruction) GetID ¶
func (i *FRBCInstruction) GetID() *generated.ID
GetID returns the instruction ID.
func (*FRBCInstruction) GetMessageID ¶
func (i *FRBCInstruction) GetMessageID() *generated.ID
GetMessageID returns the message ID.
func (*FRBCInstruction) GetMessageType ¶
func (i *FRBCInstruction) GetMessageType() string
GetMessageType returns the message type.
func (*FRBCInstruction) GetOperationMode ¶
func (i *FRBCInstruction) GetOperationMode() *generated.ID
GetOperationMode returns the operation mode ID.
func (*FRBCInstruction) GetOperationModeFactor ¶
func (i *FRBCInstruction) GetOperationModeFactor() float64
GetOperationModeFactor returns the operation mode factor.
type FRBCLeakageBehaviour ¶
type FRBCLeakageBehaviour struct {
Elements []*FRBCLeakageBehaviourElement `` /* 152-byte string literal not displayed */
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBC.LeakageBehaviour"`
ValidFrom time.Time `` /* 184-byte string literal not displayed */
}
FRBCLeakageBehaviour represents the leakage behaviour of the buffer.
func NewFRBCLeakageBehaviour ¶
func NewFRBCLeakageBehaviour(elements []*FRBCLeakageBehaviourElement, validFrom time.Time) (*FRBCLeakageBehaviour, error)
NewFRBCLeakageBehaviour creates a new instance of FRBCLeakageBehaviour if validated, otherwise returns an error.
func (*FRBCLeakageBehaviour) GetElements ¶
func (lb *FRBCLeakageBehaviour) GetElements() []*FRBCLeakageBehaviourElement
GetElements returns the elements of the leakage behaviour.
func (*FRBCLeakageBehaviour) GetMessageID ¶
func (lb *FRBCLeakageBehaviour) GetMessageID() *generated.ID
GetMessageID returns the message ID of the leakage behaviour.
func (*FRBCLeakageBehaviour) GetMessageType ¶
func (lb *FRBCLeakageBehaviour) GetMessageType() string
GetMessageType returns the message type of the leakage behaviour.
func (*FRBCLeakageBehaviour) GetValidFrom ¶
func (lb *FRBCLeakageBehaviour) GetValidFrom() time.Time
GetValidFrom returns the valid from timestamp of the leakage behaviour.
type FRBCLeakageBehaviourElement ¶
type FRBCLeakageBehaviourElement struct {
FillLevelRange *common.NumberRange `` /* 173-byte string literal not displayed */
LeakageRate float64 `` /* 158-byte string literal not displayed */
}
FRBCLeakageBehaviourElement represents an element of FRBC leakage behavior.
func NewFRBCLeakageBehaviourElement ¶
func NewFRBCLeakageBehaviourElement(fillLevelRange *common.NumberRange, leakageRate float64) (*FRBCLeakageBehaviourElement, error)
NewFRBCLeakageBehaviourElement creates a new instance of FRBCLeakageBehaviourElement if validation is correct, otherwise returns an error.
func (*FRBCLeakageBehaviourElement) GetFillLevelRange ¶
func (e *FRBCLeakageBehaviourElement) GetFillLevelRange() *common.NumberRange
GetFillLevelRange returns the fill level range of the FRBCLeakageBehaviourElement.
func (*FRBCLeakageBehaviourElement) GetLeakageRate ¶
func (e *FRBCLeakageBehaviourElement) GetLeakageRate() float64
GetLeakageRate returns the leakage rate of the FRBCLeakageBehaviourElement.
type FRBCOperationMode ¶
type FRBCOperationMode struct {
AbnormalConditionOnly bool `` /* 127-byte string literal not displayed */
DiagnosticLabel *string `` /* 190-byte string literal not displayed */
Elements []*FRBCOperationModeElement `` /* 219-byte string literal not displayed */
ID *generated.ID `` /* 134-byte string literal not displayed */
}
FRBCOperationMode represents an FRBC operation mode.
func NewFRBCOperationMode ¶
func NewFRBCOperationMode(abnormalConditionOnly bool, elements []*FRBCOperationModeElement, label *string) (*FRBCOperationMode, error)
NewFRBCOperationMode creates a new instance of FRBCOperationMode if validated, otherwise returns an error.
func (*FRBCOperationMode) GetAbnormalConditionOnly ¶
func (m *FRBCOperationMode) GetAbnormalConditionOnly() bool
GetAbnormalConditionOnly returns whether the operation mode is for abnormal conditions only.
func (*FRBCOperationMode) GetDiagnosticLabel ¶
func (m *FRBCOperationMode) GetDiagnosticLabel() *string
GetDiagnosticLabel returns the diagnostic label of the operation mode.
func (*FRBCOperationMode) GetElements ¶
func (m *FRBCOperationMode) GetElements() []*FRBCOperationModeElement
GetElements returns the elements of the operation mode.
func (*FRBCOperationMode) GetID ¶
func (m *FRBCOperationMode) GetID() *generated.ID
GetID returns the ID of the operation mode.
type FRBCOperationModeElement ¶
type FRBCOperationModeElement struct {
FillLevelRange *common.NumberRange `` /* 194-byte string literal not displayed */
FillRate *common.NumberRange `` /* 234-byte string literal not displayed */
PowerRanges []*common.PowerRange `` /* 354-byte string literal not displayed */
RunningCosts *common.NumberRange `` /* 299-byte string literal not displayed */
}
FRBCOperationModeElement represents an element of FRBC operation mode.
func NewFRBCOperationModeElement ¶
func NewFRBCOperationModeElement(fillLevelRange, fillRate *common.NumberRange, powerRanges []*common.PowerRange, runningCosts *common.NumberRange) (*FRBCOperationModeElement, error)
NewFRBCOperationModeElement creates a new instance of FRBCOperationModeElement if validation is correct, otherwise returns an error.
func (*FRBCOperationModeElement) GetFillLevelRange ¶
func (e *FRBCOperationModeElement) GetFillLevelRange() *common.NumberRange
GetFillLevelRange returns the fill level range of the FRBCOperationModeElement.
func (*FRBCOperationModeElement) GetFillRate ¶
func (e *FRBCOperationModeElement) GetFillRate() *common.NumberRange
GetFillRate returns the fill rate of the FRBCOperationModeElement.
func (*FRBCOperationModeElement) GetPowerRanges ¶
func (e *FRBCOperationModeElement) GetPowerRanges() []*common.PowerRange
GetPowerRanges returns the power ranges of the FRBCOperationModeElement.
func (*FRBCOperationModeElement) GetRunningCosts ¶
func (e *FRBCOperationModeElement) GetRunningCosts() *common.NumberRange
GetRunningCosts returns the running costs of the FRBCOperationModeElement, if any.
type FRBCStorageDescription ¶
type FRBCStorageDescription struct {
DiagnosticLabel *string `` //pointer because its optional.
/* 214-byte string literal not displayed */
FillLevelLabel *string `` //pointer because its optional.
/* 267-byte string literal not displayed */
FillLevelRange *common.NumberRange `` /* 295-byte string literal not displayed */
ProvidesFillLevelTargetProfile bool `` /* 176-byte string literal not displayed */
ProvidesLeakageBehaviour bool `` /* 161-byte string literal not displayed */
ProvidesUsageForecast bool `` /* 136-byte string literal not displayed */
}
FRBCStorageDescription represents the description of FRBC storage.
func NewFRBCStorageDescription ¶
func NewFRBCStorageDescription(fillLevelRange *common.NumberRange, providesFillLevelTargetProfile, providesLeakageBehaviour, providesUsageForecast bool, diagnosticLabel, fillLevelLabel *string) (*FRBCStorageDescription, error)
NewFRBCStorageDescription creates a new instance of FRBCStorageDescription.
func (*FRBCStorageDescription) GetDiagnosticLabel ¶
func (sd *FRBCStorageDescription) GetDiagnosticLabel() *string
GetDiagnosticLabel returns the diagnostic label of the storage description.
func (*FRBCStorageDescription) GetFillLevelLabel ¶
func (sd *FRBCStorageDescription) GetFillLevelLabel() *string
GetFillLevelLabel returns the fill level label of the storage description.
func (*FRBCStorageDescription) GetFillLevelRange ¶
func (sd *FRBCStorageDescription) GetFillLevelRange() *common.NumberRange
GetFillLevelRange returns the fill level range of the storage description.
func (*FRBCStorageDescription) GetProvidesFillLevelTargetProfile ¶
func (sd *FRBCStorageDescription) GetProvidesFillLevelTargetProfile() bool
GetProvidesFillLevelTargetProfile returns whether the storage provides a fill level target profile.
func (*FRBCStorageDescription) GetProvidesLeakageBehaviour ¶
func (sd *FRBCStorageDescription) GetProvidesLeakageBehaviour() bool
GetProvidesLeakageBehaviour returns whether the storage provides details of power leakage behaviour.
func (*FRBCStorageDescription) GetProvidesUsageForecast ¶
func (sd *FRBCStorageDescription) GetProvidesUsageForecast() bool
GetProvidesUsageForecast returns whether the storage provides a usage forecast.
type FRBCStorageStatus ¶
type FRBCStorageStatus struct {
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBC.StorageStatus"`
PresentFillLevel float64 `json:"present_fill_level" description:"Present fill level of the Storage"`
}
FRBCStorageStatus represents the status of FRBC storage.
func NewFRBCStorageStatus ¶
func NewFRBCStorageStatus(presentFillLevel float64) (*FRBCStorageStatus, error)
NewFRBCStorageStatus creates a new instance of FRBCStorageStatus.
func (*FRBCStorageStatus) GetMessageID ¶
func (s *FRBCStorageStatus) GetMessageID() *generated.ID
GetMessageID returns the message ID of the storage status.
func (*FRBCStorageStatus) GetMessageType ¶
func (s *FRBCStorageStatus) GetMessageType() string
GetMessageType returns the message type of the storage status.
func (*FRBCStorageStatus) GetPresentFillLevel ¶
func (s *FRBCStorageStatus) GetPresentFillLevel() float64
GetPresentFillLevel returns the present fill level of the storage.
type FRBCSystemDescription ¶
type FRBCSystemDescription struct {
Actuators []*FRBCActuatorDescriptor `json:"actuators" description:"Details of all Actuators." min_items:"1" max_items:"10"`
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBC.SystemDescription"`
Storage *FRBCStorageDescription `json:"storage" description:"Details of the storage."`
ValidFrom time.Time `` /* 182-byte string literal not displayed */
}
FRBCSystemDescription represents the system description in FRBC.
func NewFRBCSystemDescription ¶
func NewFRBCSystemDescription(actuators []*FRBCActuatorDescriptor, storage *FRBCStorageDescription, validFrom time.Time) (*FRBCSystemDescription, error)
NewFRBCSystemDescription creates a new instance of FRBCSystemDescription if validated, otherwise returns an error.
func (*FRBCSystemDescription) GetActuators ¶
func (sd *FRBCSystemDescription) GetActuators() []*FRBCActuatorDescriptor
GetActuators returns the actuators of the system description.
func (*FRBCSystemDescription) GetMessageID ¶
func (sd *FRBCSystemDescription) GetMessageID() *generated.ID
GetMessageID returns the message ID of the system description.
func (*FRBCSystemDescription) GetMessageType ¶
func (sd *FRBCSystemDescription) GetMessageType() string
GetMessageType returns the message type of the system description.
func (*FRBCSystemDescription) GetStorage ¶
func (sd *FRBCSystemDescription) GetStorage() *FRBCStorageDescription
GetStorage returns the storage description of the system description.
func (*FRBCSystemDescription) GetValidFrom ¶
func (sd *FRBCSystemDescription) GetValidFrom() time.Time
GetValidFrom returns the valid from timestamp of the system description.
type FRBCTimerStatus ¶
type FRBCTimerStatus struct {
ActuatorID *generated.ID `json:"actuator_id" description:"The ID of the actuator the timer belongs to"`
FinishedAt time.Time `` /* 294-byte string literal not displayed */
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBC.TimerStatus"`
TimerID *generated.ID `json:"timer_id" description:"The ID of the timer this message refers to"`
}
FRBCTimerStatus represents the status of FRBC timer.
func NewFRBCTimerStatus ¶
func NewFRBCTimerStatus(actuator *generated.ID, timer *common.Timer, finishedAt time.Time) (*FRBCTimerStatus, error)
NewFRBCTimerStatus creates a new instance of FRBCTimerStatus.
type FRBCUsageForecast ¶
type FRBCUsageForecast struct {
Elements []FRBCUsageForecastElement `` /* 183-byte string literal not displayed */
MessageID *generated.ID `json:"message_id" description:"ID of this message"`
MessageType string `json:"message_type" description:"FRBC.UsageForecast" const:"true"`
StartTime time.Time `json:"start_time" description:"Time at which the FRBC.UsageForecast starts."`
}
FRBCUsageForecast represents the usage forecast.
func NewFRBCUsageForecast ¶
func NewFRBCUsageForecast(elements []FRBCUsageForecastElement, startTime time.Time) (*FRBCUsageForecast, error)
NewFRBCUsageForecast creates a new instance of FRBCUsageForecast if validation is correct.
type FRBCUsageForecastElement ¶
type FRBCUsageForecastElement struct {
Duration *common.Duration `json:"duration" description:"Indicator for how long the given usage_rate is valid."`
UsageRateExpected float64 `` /* 145-byte string literal not displayed */
UsageRateLower68PPR *float64 `` // Used as pointer as in case the are not included.
/* 146-byte string literal not displayed */
UsageRateLower95PPR *float64 `` // Used as pointer as in case the are not included.
/* 146-byte string literal not displayed */
UsageRateLowerLimit *float64 `` // Used as pointer as in case the are not included.
/* 147-byte string literal not displayed */
UsageRateUpper68PPR *float64 `` // Used as pointer as in case the are not included.
/* 146-byte string literal not displayed */
UsageRateUpper95PPR *float64 `` // Used as pointer as in case the are not included.
/* 147-byte string literal not displayed */
UsageRateUpperLimit *float64 `` // Used as pointer as in case the are not included.
/* 148-byte string literal not displayed */
}
FRBCUsageForecastElement represents an element of FRBC usage forecast.
func NewFRBCUsageForecastElement ¶
func NewFRBCUsageForecastElement(duration *common.Duration, usageRateExp float64) (*FRBCUsageForecastElement, error)
NewFRBCUsageForecastElement creates a new instance if validation is correct, otherwise error.
Source Files
¶
- frbcActuatorDescriptor.go
- frbcActuatorStatus.go
- frbcFillLevelTargetProfile.go
- frbcFillLevelTargetProfileElement.go
- frbcInstruction.go
- frbcLeakageBehaviour.go
- frbcLeakageBehaviourElement.go
- frbcOperationMode.go
- frbcOperationModeElement.go
- frbcStorageDescription.go
- frbcStorageStatus.go
- frbcSystemDescriptor.go
- frbcTimerStatus.go
- frbcUsageForecast.go
- frbcUsageForecastElement.go